;;; This is used to create pvs-prelude-files-and-regions.el, which is just
;;; defines *pvs-files-and-regions* so that extracting prelude theories
;;; (e.g., using M-x vpt) is reasonably quick.

(defvar start-pvs nil) ; don't need to run pvs, just load the files

(defconst pvs-emacs-system
  (cond ((string-match "Xemacs 21" (emacs-version))
	 'xemacs21)
	((string-match "XEmacs 20" (emacs-version))
	 'xemacs20)
	((string-match "XEmacs 19" (emacs-version))
	 'xemacs19)
	((string-match "Emacs 20" (emacs-version))
	 'emacs20)
	((string-match "Emacs 19" (emacs-version))
	 'emacs19)
	(t
	 (message "Your Emacs version is not known by PVS - assuming Emacs 20")
         'emacs20))
  "The version of Emacs in which PVS is running. Set in go-pvs.el.
   Defined as one of (xemacs21 xemacs20 xemacs19 emacs20 emacs19) and defaults
   to emacs20 if the current version cannot be determined.")

(defconst pvs-path "/homes/owre/pvs3.0")

(setq load-path
  (append (list pvs-path
		(concat pvs-path "/emacs/emacs-src")
		(concat pvs-path "/emacs/emacs-src/ilisp"))
          load-path))

(defvar region-file
  "emacs/emacs-src/pvs-prelude-files-and-regions.el")

(defun set-prelude-files-and-regions ()
  (let* ((files (directory-files "/homes/owre/pvs3.0/lib"
				 t "^prelude\\.pvs$\\|.*_adt\\.pvs$"))
	 (files-and-regions
	  (mapcar '(lambda (file)
		     (save-excursion
		       (let ((noninteractive t)) ;; Shut up about read-only
			 (set-buffer (find-file-noselect file)))
		       (cons (file-name-nondirectory file) (theory-regions*))))
	    files)))
    (set-buffer (find-file-noselect (format "/homes/owre/pvs3.0/%s" region-file)))
    (erase-buffer)
    (insert ";;; Generated from pvs-set-prelude-info.el - do not edit
(defvar *prelude-files-and-regions*
  (mapcar
      '(lambda (x)
	 (cons (format \"%s/lib/%s\" pvs-path (car x)) (cdr x)))
    '")
    (insert (format "%S" files-and-regions))
    (insert "))")
    (write-file (buffer-file-name))))
